/*
**      LinkView.h
**      LinkPalette, Beta Release
**      Copyright (c) 1993, Target Development.  All rights reserved. 
*/

#import <appkit/appkit.h>
#import <dbkit/dbkit.h>
#import "LinkEnums.h"

@interface LinkView:ScrollView
{
	BOOL registeredForAsciiFiles;
	unsigned int smallImageScalingBehavior;
	unsigned int largeImageScalingBehavior;
	int tag;
	
	id _set;
	id module;
	id delegate;
	id _altView;
	NXImage  *image;
	id _systemFile;
	
	char *filename;
	
	float minViewScaleFactor;
	float maxViewScaleFactor;
	float minWindowScaleFactor;
	float maxWindowScaleFactor;
	
	NXSize displaySize;
	NXSize minViewSize;
	NXSize maxViewSize;
	NXSize minWindowSize;
	NXSize maxWindowSize;
}

	// LinkView methods
+ initialize;
- initFrame:(const NXRect *)newFrame;
- awake;
- read:(NXTypedStream *)typedStream;
- write:(NXTypedStream *)typedStream;
- free;
- (const char *)getInspectorClassName;

	// Dragging Protocol
- (NXDragOperation)draggingEntered:(id <NXDraggingInfo>)sender;
- (NXDragOperation)draggingUpdated:(id <NXDraggingInfo>)sender;
- (BOOL)performDragOperation:(id <NXDraggingInfo>)sender;
- draggingExited:(id <NXDraggingInfo>)sender;

	// Custom association protocol 
- association:association setValue:(DBValue *)value;
- association:association getValue:(DBValue *)value;

	// Registering and verifying file types and names
- (BOOL)registerForFileType:(TDFileType)aType :(BOOL)flag;
- (BOOL) isRegisteredForFileType:(TDFileType)aType;
- (TDFileType)fileType:(const char *)name;
- (TDFileType)currentFileType;
- (TDErrorCode)isLoadable:(const char *)aFilename;

	// managing the docView type
- (BOOL)updateDocViewForFile:(const char *)aFilename;
- (TDDocViewType)docViewType;
- (BOOL)setDocViewToType:(TDDocViewType)aType;

	// using a module and/or a delegate
- delegate;
- setDelegate:anObject;
- module;
- setModule:aModule;
- altView;

- (BOOL)loadFile:(const char *)aFilename setName:(BOOL)aFlag;
- (BOOL)loadFileFromPanel:(const char *)startingPoint setName:(BOOL)aFlag;
- image;
- setImage:anImage;
- (const char *)currentFilename;
- setCurrentFilename:(const char *)aFilename;

- (BOOL)saveFile:(const char *)aFilename;
- (BOOL)saveWithPanel;

- displayImage:anImage atSize:(NXSize *)aSize usingScalingBehavior:(TDScalingBehavior)anInt;
- scaleImage:anImage inViewBy:(float)aFactor;
- clearDisplay:sender;

	// copying / returning image
- copyImage:anImage toSize:(NXSize *)aSize;

	// compositing in new windows
- displayImage:anImage inWindowOfSize:(NXSize *)aSize;
- displayOriginalImageInNewWindow:sender;
- displayCurrentImageInNewWindow:sender;
- scaleImage:anImage inNewWindowBy:(float)aFactor;

	// Text Object methods
- (TDErrorCode)openTextFile:(const char *)aFilename inApp:(const char *)appName;

	// Assigning a tag
- (int)tag;
- setTag:(int)anInt;

	// setting / testing image behavior based on image size versus view size
- (BOOL) imageIsLargerThanView:anImage;
- setSmallImageScalingBehavior:(TDScalingBehavior)anInt;
- (TDScalingBehavior)smallImageScalingBehavior;
- setLargeImageScalingBehavior:(TDScalingBehavior)anInt;
- (TDScalingBehavior)largeImageScalingBehavior;

	// setting min and max view sizes and scaling factors
- (float)maxViewScaleFactor;
- (BOOL)setMaxViewScaleFactor:(float)aFactor;
- (float)minViewScaleFactor;
- (BOOL)setMinViewScaleFactor:(float)aFactor;
- (BOOL)setMaxViewSize:(NXSize *)aSize;
- getMaxViewSize:(NXSize *)aSize;
- (BOOL)setMinViewSize:(NXSize *)aSize;
- getMinViewSize:(NXSize *)aSize;
- validateViewSize:(NXSize *)validSize fromSize:(NXSize *)theSize adjustProportionally:(BOOL)aFlag;

	// setting min and max window sizes and scaling factors
- (float)maxWindowScaleFactor;
- (BOOL)setMaxWindowScaleFactor:(float)aFactor;
- (float)minWindowScaleFactor;
- (BOOL)setMinWindowScaleFactor:(float)aFactor;
- (BOOL)setMaxWindowSize:(NXSize *)aSize;
- getMaxWindowSize:(NXSize *)aSize;
- (BOOL)setMinWindowSize:(NXSize *)aSize;
- getMinWindowSize:(NXSize *)aSize;
- validateWindowSize:(NXSize *)validSize fromSize:(NXSize *)theSize;

@end

@interface Object(LinkViewDelegate)

- (BOOL)fileWillLoad:(const char *)aFilename ofType:(TDFileType)aType;
- fileDidLoad:(const char *)aFilename ofType:(TDFileType)aType;
- file:(const char *)aFilename ofType:(TDFileType)aType didNotLoadForReason:(TDErrorCode) aCode;

- (BOOL)fileWillSave:(const char *)aFilename ofType:(TDFileType)aType;
- fileDidSave:(const char *)aFilename ofType:(TDFileType)aType;
- file:(const char *)aFilename ofType:(TDFileType)aType didNotSaveForReason:(TDErrorCode)aCode;
- (const char *)cannotSaveFile:(const char *)invalidFile ofType:(TDFileType)aType usingFile:(const char *)validFile;

- (float)viewScaleFactor:(float)origFactor adjustedTo:(float)adjustedFactor;
- (float)windowScaleFactor:(float)origFactor adjustedTo:(float)adjustedFactor;

- imageOfSize:(NXSize *)theSize willDisplayAtSize:(NXSize *)validSize;
- windowOfSize:(NXSize *)theSize willDisplayAtSize:(NXSize *)validSize;
- windowOfSize:(NXSize *)theSize willDisplayAtPoint:(NXPoint *)screenPoint;

- (const char *)validatePathForFile:(const char *)aFilename ofType:(TDFileType)aType;
- (const char *)cannotLoadFile:(const char *)invalidName ofType:(TDFileType)aType usingFile:(const char *)validName;

@end
