/*
** DocController.m
**
** You may freely copy, distribute, and reuse the code in this example.
** Target Development disclaims any warranty of any kind, expressed or 
** implied, as to it's fitness for any particular use.
**
*/

#import "DocController.h"

@implementation DocController

- awakeFromNib
{
		// we must make the association to the LinkView programmatically
				
	[[docModule rootFetchGroup] makeAssociationFrom:[[docModule entity] propertyNamed:"doc_path"] to:docScrollView];
				
	return self;
}

- newDoc:sender
{
	[docModule insertNewRecord:self];
	
	[controller uniqueKeyForProperty:"doc_id" intoFetchGroup:[docModule rootFetchGroup]];
	
	return self;
}

- loadTextFile:sender
{
	[docScrollView loadFile:[sender stringValue] setName:NO];
		
	return self;
}

- openInApp:sender
{
	[docScrollView openTextFile:[docScrollView currentFilename] inApp:NULL];
	
	return self;
}

- saveDocFile:sender
{	
	// save the current document to the file specified by the sender
	
	[docScrollView saveFile:[sender stringValue]];
	
	return self;
}

- saveDocWithPanel:sender
{
	[docScrollView saveWithPanel];
	
	return self;
}

	/*********************** Doc Window Delegate Methods **********************/

- fileDidLoad:(const char *)filename ofType:(TDFileType)aType
{		
			// Work around used to update the document
			// path names...bug seems to be
			//  related to the fact the connections can
			//  not be made graphically to the LinkView 
			
	[docPathName setStringValue:filename];
		
	return self;
}

- file:(const char *)filename ofType:(TDFileType)aType didNotLoadForReason:(TDErrorCode)aCode;
{
	[docScrollView clearDisplay:self];
		
	switch(aCode) {
		case TD_INVALID_TYPE:
			printf("Load Doc - Invalid File Type\n");
			break;
		case TD_TYPE_NOT_REGISTERED:
			printf("Load Doc - Type Not Registered By Object\n");
			break;
		case TD_FILE_DOES_NOT_EXIST:
			printf("Load Doc - File Does Not Exist\n");
			break;
		case TD_FILE_COPY_FAILED:
			printf("Load Doc - File Copy Failed\n");
			break;
		case TD_FILE_IS_NULL:
			printf("Load Doc - File is NULL\n");
			break;
		case TD_FILE_PERMISSION_DENIED:
			printf("Load Doc - File Permission Denied\n");
			break;
		case TD_DIR_PERMISSION_DENIED:
			printf("Load Doc - Directory Permission Denied\n");
			break;
		case TD_REJECTED_BY_DELEGATE:
			printf("Load Doc - Rejected By Delegate\n");
			break;
		case TD_INVALID_PATH:
			printf("Load Doc - Invalid Path... Renaming file\n");
			break;
		case TD_OBJECT_IS_NIL:
			printf("Load Doc - Object is NIL\n");
			break;
		case TD_UNKNOWN_ERROR:
			printf("Load Doc - Unknown Error\n");
			break;
		case TD_NO_ERROR:
			// This case will never occur
			break;
	}
	
	return self;
}

- (const char *)validatePathForFile:(const char *)aFilename ofType:(TDFileType)aType
{		
	return "/LocalLibrary/LinkedFiles/Documents/";
}

- (const char *)cannotLoadFile:(const char *)invalidFile ofType:(TDFileType)anInt usingFile:(const char *)validFile
{	
	int alert = -1;

	alert = NXRunAlertPanel("Invalid File Name","File %s Not From Controlled Directory.  Use name %s instead","Original Name", "New Name", "Cancel", invalidFile, validFile);	

	if (alert == 1) 
		return invalidFile;
	else if (alert == 0)
		return validFile;
		
	return NULL;
}

- file:(const char *)aFilename ofType:(TDFileType)aType didNotSaveForReason:(TDErrorCode)aCode
{	
	switch(aCode) {
		case TD_INVALID_TYPE:
			printf("Save Doc - Invalid File Type\n");
			break;
		case TD_TYPE_NOT_REGISTERED:
			printf("Save Doc - Type Not Registered\n");
			break;
		case TD_FILE_DOES_NOT_EXIST:
			printf("Save Doc - File Does Not Exist\n");
			break;
		case TD_FILE_COPY_FAILED:
			printf("Save Doc - File Copy Failed\n");
			break;
		case TD_FILE_IS_NULL:
			printf("Save Doc - File is NULL\n");
			break;
		case TD_FILE_PERMISSION_DENIED:
			printf("Save Doc - File Permission Denied\n");
			break;
		case TD_DIR_PERMISSION_DENIED:
			printf("Save Doc - Directory Permission Denied\n");
			break;
		case TD_REJECTED_BY_DELEGATE:
			printf("Save Doc - Rejected By Delegate\n");
			break;
		case TD_INVALID_PATH:
			printf("Save Doc - Invalid Path\n");
			break;
		case TD_OBJECT_IS_NIL:
			printf("Save Doc - Object is NIL\n");
			break;
		case TD_UNKNOWN_ERROR:
			printf("Save Doc - Unknown Error\n");
			break;
		case TD_NO_ERROR:
			// This case will never occur
			printf("No ERROR ???\n");
			break;
	}
	
	return self;
}

- (const char *)cannotSaveFile:(const char *)validFile ofType:(TDFileType)aType usingFile:(const char *)invalidFile
{
	int alert = -1;
	
	alert = NXRunAlertPanel("Invalid File Name","File %s Not A Controlled Directory.  Save name %s instead","Original Name", "New Name", "Cancel", validFile, invalidFile);	

	if (alert == 1) 
		return validFile;
	else if (alert == 0)
		return invalidFile;

		
	return NULL;
}

@end
