/*
** ImageController.m
**
** You may freely copy, distribute, and reuse the code in this example.
** Target Development disclaims any warranty of any kind, expressed or 
** implied, as to it's fitness for any particular use.
**
*/

#import "ImageContoller.h"

@implementation ImageContoller

- awakeFromNib
{
		// association to the LinkView must be made programmatically
		
	[[imageModule rootFetchGroup] makeAssociationFrom:[[imageModule entity] propertyNamed:"image_path"] to:imageScrollView];
		
		// set default coordinates for new window
	[xcoord setIntValue:100];
	[ycoord setIntValue:100];
	
	return self;
}

- newImage:sender
{
	[imageModule insertNewRecord:self];
	
	[controller uniqueKeyForProperty:"image_id" intoFetchGroup:[imageModule rootFetchGroup]];
	
	return self;
}

- setScaleBehavior:sender    
{	
	if ([[scaleMatrix selectedCell] tag] == 0)
		[imageScrollView setSmallImageScalingBehavior:[[sender selectedCell] tag]];
	else
		[imageScrollView setLargeImageScalingBehavior:[[sender selectedCell] tag]];

	[imageScrollView displayImage:nil atSize:NULL usingScalingBehavior:-1];
	 
	return self; 
}

- scaleInView:sender
{
	[imageScrollView scaleImage:nil inViewBy:[sender floatValue]];
	
	[sender selectText:self];
	
	return self; 
}

- scaleInWindow:sender
{
	id theWindow;
	
	theWindow = [imageScrollView scaleImage:nil inNewWindowBy:[sender floatValue]];
	
	[sender selectText:self];

	return self;
}

- loadImageFile:sender
{
	[imageScrollView loadFile:[sender stringValue] setName:NO];
		
	return self;
}

- loadImageFromPanel:sender
{
	[imageScrollView loadFileFromPanel:"/LocalLibrary/LinkedFiles/Images/" setName:YES];
		
	return self;
}

- saveImageFile:sender
{	
	// save the current image to the file specified by the sender
	
	[imageScrollView saveFile:[sender stringValue]];
	
	return self;
}

- saveImageWithPanel:sender
{
	[imageScrollView saveWithPanel];
	
	return self;
}

	/******* Image Window Delegate Methods *******/

- fileDidLoad:(const char *)filename ofType:(TDFileType)aType
{
	if ([imageScrollView imageIsLargerThanView:nil])
		[scaleMatrix selectCellWithTag:1];
	else
		[scaleMatrix selectCellWithTag:0];
		
			// Work around used to update the document
			//  and image path names...bug seems to be
			//  related to the fact the connections can
			//  not be made graphically to the LinkView 
			
	[imagePathName setStringValue:filename];
		
	return self;
}

- file:(const char *)filename ofType:(TDFileType)aType didNotLoadForReason:(TDErrorCode)aCode;
{
    id theImage = nil;
	char        buf[MAXPATHLEN + 1];
	NXBundle   *bundle;
	
	if (aCode == TD_FILE_IS_NULL) {	
		switch ([[defaultImage selectedCell] tag]) {
				
			case 0:
				bundle = [NXBundle bundleForClass:[self class]];
				[bundle getPath:buf forResource:"LinkView" ofType:"tiff"];
				theImage = [[NXImage alloc] initFromFile:buf];
				[imageScrollView displayImage:theImage atSize:NULL usingScalingBehavior:TD_NO_SCALING];
				break;
					
			case 1:
				bundle = [NXBundle bundleForClass:[self class]];
				[bundle getPath:buf forResource:"TargetDev" ofType:"tiff"];
				theImage = [[NXImage alloc] initFromFile:buf];
				[imageScrollView displayImage:theImage atSize:NULL usingScalingBehavior:TD_SCALE_IMAGE_TO_FIT_VIEW];
				break;		
				
			case 2:
				[imageScrollView clearDisplay:self];
				break;		
		}
	}
	
	switch(aCode) {
		case TD_INVALID_TYPE:
			printf("Load Image - Invalid File Type\n");
			break;
		case TD_TYPE_NOT_REGISTERED:
			printf("Load Image - Type Not Registered By Object\n");
			break;
		case TD_FILE_DOES_NOT_EXIST:
			printf("Load Image - File Does Not Exist\n");
			break;
		case TD_FILE_PERMISSION_DENIED:
			printf("Load Image - File Permission Denied\n");
			break;
		case TD_DIR_PERMISSION_DENIED:
			printf("Load Image - Directory Permission Denied\n");
			break;
		case TD_REJECTED_BY_DELEGATE:
			printf("Load Image - Rejected By Delegate\n");
			break;
		case TD_INVALID_PATH:
			printf("Load Image - Invalid Path... Renaming file\n");
			break;
		case TD_OBJECT_IS_NIL:
			printf("Load Image - Object is NIL\n");
			break;
		case TD_FILE_IS_NULL:
			printf("Load Image - File is NULL\n");
			break;
		case TD_FILE_COPY_FAILED:
			printf("Load Image - File Copy Failed\n");
			break;
		case TD_UNKNOWN_ERROR:
			printf("Load Image - Unknown Error\n");
			break;
		case TD_NO_ERROR:
			// This case will never occur
			break;
	}
	return self;
}

- imageOfSize:(NXSize *)theSize willDisplayAtSize:(NXSize *)validSize
{
	if (theSize->height != validSize->height || theSize->width != validSize->width) {
		
		NXRunAlertPanel("Image Size Offends Default Bounds","Adjusting from Size %f :%f to size %f : %f\n",NULL,NULL,NULL,theSize->height, theSize->width, validSize->height, validSize->width);
	
	//  alter display size to desired size here
	//	validSize->height = 300;
	//	validSize->width = 300;
	
	}
	return self;
}

- windowOfSize:(NXSize *)theSize willDisplayAtSize:(NXSize *)validSize
{
	if (theSize->height != validSize->height || theSize->width != validSize->width) {
	
		NXRunAlertPanel("Window Size Offends Default Bounds","Adjusting from Size %f :%f to size %f : %f\n",NULL,NULL,NULL,theSize->height, theSize->width, validSize->height, validSize->width);
	
	//  alter display size to desired size here
	
	//	validSize->height = 300;
	//	validSize->width = 300;
	}
	return self;
}

- windowOfSize:(NXSize *)validSize willDisplayAtPoint:(NXPoint *)screenPoint
{
	screenPoint->x = [xcoord intValue];
	screenPoint->y = [ycoord intValue];
	
	return self;
}

- (float)viewScaleFactor:(float)origFactor adjustedTo:(float)adjustedFactor
{
	NXRunAlertPanel("Invalid VIEW Scale Factor","Adjusting from factor %f to %f\n",NULL,NULL,NULL,origFactor, adjustedFactor);

	[viewScaleFactor setFloatValue:adjustedFactor];
	
	return adjustedFactor;
}

- (float)windowScaleFactor:(float)origFactor adjustedTo:(float)adjustedFactor
{
	NXRunAlertPanel("Invalid WINDOW Scale Factor","Adjusting from factor %f to %f\n",NULL,NULL,NULL,origFactor, adjustedFactor);

	[windowScaleFactor setFloatValue:adjustedFactor];
	
	return adjustedFactor;
}

- (const char *)validatePathForFile:(const char *)aFilename ofType:(TDFileType)aType
{
	// Name of directories where images and documents are to reside, respectively
		
	return "/LocalLibrary/LinkedFiles/Images/";
}

- (const char *)cannotLoadFile:(const char *)invalidFile ofType:(TDFileType)anInt usingFile:(const char *)validFile
{	
	int alert = -1;

	alert = NXRunAlertPanel("Invalid File Name","File %s Not From Controlled Directory.  Use name %s instead","Original Name", "New Name", "Cancel", invalidFile, validFile);	

	if (alert == 1) 
		return invalidFile;
	else if (alert == 0)
		return validFile;
		
	return NULL;
}

- file:(const char *)aFilename ofType:(TDFileType)aType didNotSaveForReason:(TDErrorCode)aCode
{	
	switch(aCode) {
		case TD_INVALID_TYPE:
			printf("Save Image - Invalid File Type\n");
			break;
		case TD_TYPE_NOT_REGISTERED:
			printf("Save Image - Type Not Registered\n");
			break;
		case TD_FILE_DOES_NOT_EXIST:
			printf("Save Image - File Does Not Exist\n");
			break;
		case TD_FILE_COPY_FAILED:
			printf("Save Image - File Copy Failed\n");
			break;
		case TD_FILE_IS_NULL:
			printf("Save Image - File is NULL\n");
			break;
		case TD_FILE_PERMISSION_DENIED:
			printf("Save Image - File Permission Denied\n");
			break;
		case TD_DIR_PERMISSION_DENIED:
			printf("Save Image - Directory Permission Denied\n");
			break;
		case TD_REJECTED_BY_DELEGATE:
			printf("Save Image - Rejected By Delegate\n");
			break;
		case TD_INVALID_PATH:
			printf("Save Image - Invalid Path\n");
			break;
		case TD_OBJECT_IS_NIL:
			printf("Save Image - Object is NIL\n");
			break;
		case TD_UNKNOWN_ERROR:
			printf("Save Image - Unknown Error\n");
			break;
		case TD_NO_ERROR:
			// This case will never occur
			printf("No ERROR ???\n");
			break;
	}
	
	return self;
}

- (const char *)cannotSaveFile:(const char *)validFile ofType:(TDFileType)aType usingFile:(const char *)invalidFile
{
	int alert = -1;
	
	alert = NXRunAlertPanel("Invalid File Name","File %s Not A Controlled Directory.  Save name %s instead","Original Name", "New Name", "Cancel", validFile, invalidFile);	

	if (alert == 1)
		return validFile;

	else if (alert == 0)
		return invalidFile;

	return NULL;
}



@end
