/*
** SoundController.m
**
** You may freely copy, distribute, and reuse the code in this example.
** Target Development disclaims any warranty of any kind, expressed or 
** implied, as to it's fitness for any particular use.
**
*/

#import "SoundController.h"

@implementation SoundController

- newSound:sender
{
	[soundModule insertNewRecord:self];
	
	[controller uniqueKeyForProperty:"snd_id" intoFetchGroup:[soundModule rootFetchGroup]];
	
	return self;
}

- loadSoundFile:sender
{
	[[soundWell linkSound] loadSoundFromFile:[sender stringValue] setName:YES];
	
	return self;
}

- loadSoundFromPanel:sender
{
	[[soundWell linkSound] loadSoundFromPanel:"/NextLibrary/Sounds/" setName:YES];
	
	return self;
}

- useSound:sender
{
	id theSound = [[soundWell linkSound] sound];
	
	if (theSound) {
		switch([[sender selectedCell] tag]) {
			case 0:
				[theSound play];
				break;
			case 1:
				[theSound record];
				break;
			case 2:
				[theSound stop];
				break;
			case 3:
				[theSound pause];
				break;
		}
	}
	return self;
}

- saveSoundFile:sender
{	
	// save the current sound to the file specified by the sender
	
	[[soundWell linkSound] saveSoundToFile:[sender stringValue]];
	
	return self;
}

- saveSoundFromPanel:sender
{
	[[soundWell linkSound] saveSoundWithPanel];
	
	return self;
}

	/******* Sound Window Delegate Methods *******/

- soundDidNotLoadFromFile:(const char *)aFilename forReason:(TDErrorCode)aCode
{
	// sound file did not load, so load sound file corresponding to matrix selection
  
    id theSound = nil;
	char        buf[MAXPATHLEN + 1];
	NXBundle   *bundle;
	
	if (aCode == TD_FILE_IS_NULL) {
		switch ([[defaultSound selectedCell] tag]) {
			
			case 0:						// load Homer Simpson
				bundle = [NXBundle bundleForClass:[self class]];
				[bundle getPath:buf forResource:"Homer" ofType:"snd"];
				theSound = [[Sound allocFromZone:[self zone]] initFromSoundfile:buf];
				break;
				
			case 1:						// load Breaking Glass
				bundle = [NXBundle bundleForClass:[self class]];
				[bundle getPath:buf forResource:"Glass" ofType:"snd"];
				theSound = [[Sound allocFromZone:[self zone]] initFromSoundfile:buf];
				break;
		}
	
		[[soundWell linkSound] setSound:theSound];	
	}
	
	switch(aCode) {
		case TD_INVALID_TYPE:
			printf("Load Sound - Invalid File Type\n");
			break;
		case TD_TYPE_NOT_REGISTERED:
			printf("Load Sound - Type Not Registered\n");
			break;
		case TD_FILE_DOES_NOT_EXIST:
			printf("Load Sound - File Does Not Exist\n");
			break;
		case TD_FILE_COPY_FAILED:
			printf("Load Sound - File Copy Failed\n");
			break;
		case TD_FILE_IS_NULL:
			printf("Load Sound - File is NULL\n");
			break;
		case TD_FILE_PERMISSION_DENIED:
			printf("Load Sound - File Permission Denied\n");
			break;
		case TD_DIR_PERMISSION_DENIED:
			printf("Load Sound - Directory Permission Denied\n");
			break;
		case TD_REJECTED_BY_DELEGATE:
			printf("Load Sound - Rejected By Delegate\n");
			break;
		case TD_INVALID_PATH:
			printf("Load Sound - Invalid Path\n");
			break;
		case TD_OBJECT_IS_NIL:
			printf("Load Sound - Object is NIL\n");
			break;
		case TD_UNKNOWN_ERROR:
			printf("Load Sound - Unknown Error\n");
			break;
		case TD_NO_ERROR:
			// This case will never occur
			printf("No ERROR ???\n");
			break;
	}
	
	return self;
}	

- (const char *)validatePathForSoundFile:(const char *)aFilename
{
		return "/LocalLibrary/LinkedFiles/Sounds/";
}

- (const char *)cannotLoadSoundFromFile:(const char *)invalidName usingFile:(const char *)validName
{
	int alert = -1;
	
	alert = NXRunAlertPanel("Invalid File Name","File %s Not From Controlled Directory.  Use name %s instead","Original Name", "New Name", "Cancel", invalidName, validName);	

	if (alert == 1) 
		return invalidName;
	else if (alert == 0)
		return validName;
		
	return NULL;
}

- soundDidNotSaveToFile:(const char *)aFilename forReason:(TDErrorCode)aCode
{
	switch(aCode) {
		case TD_INVALID_TYPE:
			printf("Save Sound - Invalid File Type\n");
			break;
		case TD_TYPE_NOT_REGISTERED:
			printf("Save Sound -Type Not Registered\n");
			break;
		case TD_FILE_DOES_NOT_EXIST:
			printf("Save Sound - File Does Not Exist\n");
			break;
		case TD_FILE_COPY_FAILED:
			printf("Save Sound - File Copy Failed\n");
			break;
		case TD_FILE_IS_NULL:
			printf("Save Sound - File is NULL\n");
			break;
		case TD_FILE_PERMISSION_DENIED:
			printf("Save Sound - File Permission Denied\n");
			break;
		case TD_DIR_PERMISSION_DENIED:
			printf("Save Sound - Directory Permission Denied\n");
			break;
		case TD_REJECTED_BY_DELEGATE:
			printf("Save Sound - Rejected By Delegate\n");
			break;
		case TD_INVALID_PATH:
			printf("Save Sound - Invalid Path\n");
			break;
		case TD_OBJECT_IS_NIL:
			printf("Save Sound - Object is NIL\n");
			break;
		case TD_UNKNOWN_ERROR:
			printf("Save Sound - Unknown Error\n");
			break;
		case TD_NO_ERROR:
			// This case will never occur
			printf("No ERROR ???\n");
			break;
	}
	
	return self;
}

- (const char *)cannotSaveSoundToFile:(const char *)validFile usingFile:(const char *)invalidFile
{
	int alert = -1;
	
	alert = NXRunAlertPanel("Invalid File Name","File %s Not A Controlled Directory.  Save name %s instead","Original Name", "New Name", "Cancel", validFile, invalidFile);	

	if (alert == 1) 
		return invalidFile;
	else if (alert == 0)
		return validFile;
		
	return NULL;
}



@end
